@@ -12,6 +12,7 @@ valid_args_list = ['-d','--debugger', '-cj', '--css-js', '-dc', '--docker-contai
 def get_app_name():
   try:
       app_name = sys.argv[1]
+      print("NAME: " + app_name)
   except:
       print('App name cannot be empty. Please consider using --help')
       empty_name()
@@ -27,13 +28,10 @@ def is_name_valid(app_name):
 #get all arguments passed
 def get_args():
   args = sys.argv
-  print(args)
   args.pop(0)
-  print(args)
   return args
 
 def is_args_valid(args):
-  print('test-2')
   valid_args =  all(arg in valid_args_list for arg in args)
   return valid_args
 
